embassy-stm32

Crates

git

Versions

stm32h745xg-cm7

Flavors

FullBridgeConverter

Struct FullBridgeConverter 

pub struct FullBridgeConverter<T: Instance, CH1: AdvancedChannel<T>, CH2: AdvancedChannel<T>> { /* private fields */ }
Fixed-frequency full-bridge converter driver.

Implementations

Source

impl<T: Instance, CH1: AdvancedChannel<T>, CH2: AdvancedChannel<T>> FullBridgeConverter<T, CH1, CH2>

pub fn new(_ch1: &mut CH1, _ch2: &mut CH2, frequency: Hertz) -> Self

Create a new HRTIM bridge converter driver.

pub fn start(&mut self)

Start HRTIM.

pub fn stop(&mut self)

Stop HRTIM.

pub fn get_max_compare_value_master(&mut self) -> u16

Get the maximum compare value of a duty cycle

pub fn get_max_compare_value_ch1(&mut self) -> u16

Get the maximum compare value of a duty cycle

pub fn get_max_compare_value_ch2(&mut self) -> u16

Get the maximum compare value of a duty cycle

pub fn set_dead_time(&mut self, value: u16)

Set the dead time as a proportion of the maximum compare value

pub fn set_duty(&mut self, requested_duty: u16)

The duty is the period in which the primary switch is active

pub fn enable_outputs(&mut self)

The duty is the period in which the primary switch is active

pub fn disable_outputs(&mut self)

The duty is the period in which the primary switch is active

pub fn set_minimum_duty(&mut self, duty: u16)

Set minimum FET pulse width in counts